# linreg

## Description

This is a personal demo to get familiar with  the numpy arrays and linear regression algorithm. 


package contains a linear regression class with fit and predict functions. 


## Example
from # from linreg.regressors import LinearRegression

regressor=LinearRegression()
regressor.fit(X,y)
y_predict=regressor.predict(X_predict)
